@@ -1,4 +1,4 @@
-/*  $Id: GameEngine.cpp,v 1.5 2008/11/16 05:22:30 sarrazip Exp $
+/*  $Id: GameEngine.cpp,v 1.6 2009/03/10 02:35:13 sarrazip Exp $
     GameEngine.cpp - Abstract class representing an X11 Game Engine.
 
     flatzebra - Generic 2D Game Engine library
@@ -174,8 +174,8 @@ GameEngine::writeString(const char *s, Couple pos, SDL_Surface *surface)
     if (surface == NULL)
 	surface = theSDLScreen;
     Couple fontDim = getFontDimensions();
-    SDL_Rect dest = { pos.x, pos.y, fontDim.x, fontDim.y };
-    for (size_t i = 0; s[i] != '\0'; i++, dest.x += fontDim.x)
+    SDL_Rect dest = { Sint16(pos.x), Sint16(pos.y), Uint16(fontDim.x), Uint16(fontDim.y) };
+    for (size_t i = 0; s[i] != '\0'; i++, dest.x += Sint16(fontDim.x))
     {
 	unsigned char c = (unsigned char) s[i];
 	if (c < 32 || (c >= 127 && c <= 160))  // if ctrl char or undef char
@@ -190,7 +190,7 @@ GameEngine::writeString(const char *s, Couple pos, SDL_Surface *surface)
 	    y -= 2;
 	y *= fontDim.y;
 
-	SDL_Rect src  = { x, y, fontDim.x, fontDim.y };
+	SDL_Rect src  = { Sint16(x), Sint16(y), Uint16(fontDim.x), Uint16(fontDim.y) };
 	SDL_BlitSurface(fixedWidthFontPixmap, &src, surface, &dest);
     }
 }
